==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/zh-HK/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'a_user_canceled' => 'A user has canceled an item request on the website',
    'a_user_requested' => 'A user has requested an item on the website',
    'accessory_name' => 'Accessory Name:',
    'additional_notes' => 'Additional Notes:',
    'admin_has_created' => 'An administrator has created an account for you on the :web website.',
    'asset' => 'Asset:',
    'asset_name' => 'Asset Name:',
    'asset_requested' => 'Asset requested',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Assigned To',
    'best_regards' => 'Best regards,',
    'canceled' => 'Canceled:',
    'checkin_date' => 'Checkin Date:',
    'checkout_date' => 'Checkout Date:',
    'click_to_confirm' => 'Please click on the following link to confirm your :web account:',
    'click_on_the_link_accessory' => 'Please click on the link at the bottom to confirm that you have received the accessory.',
    'click_on_the_link_asset' => 'Please click on the link at the bottom to confirm that you have received the asset.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Current QTY',
    'Days' => 'Days',
    'days' => 'Days',
    'expecting_checkin_date' => 'Expected Checkin Date:',
    'expires' => 'Expires',
    'Expiring_Assets_Report' => 'Expiring Assets Report.',
    'Expiring_Licenses_Report' => 'Expiring Licenses Report.',
    'hello' => 'Hello',
    'hi' => 'Hi',
    'i_have_read' => 'I have read and agree to the terms of use, and have received this item.',
    'item' => '項目:',
    'Item_Request_Canceled' => 'Item Request Canceled',
    'Item_Requested' => 'Item Requested',
    'link_to_update_password' => 'Please click on the following link to update your :web password:',
    'login_first_admin' => 'Login to your new Snipe-IT installation using the credentials below:',
    'login' => 'Login:',
    'Low_Inventory_Report' => 'Low Inventory Report',
    'inventory_report' => 'Inventory Report',
    'min_QTY' => 'Min QTY',
    'name' => 'Name',
    'new_item_checked' => 'A new item has been checked out under your name, details are below.',
    'password' => 'Password:',
    'password_reset' => 'Password Reset',

    'read_the_terms' => 'Please read the terms of use below.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read
                         and agree to the terms of use, and have received the asset.',
    'requested' => 'Requested:',
    'reset_link' => 'Your Password Reset Link',
    'reset_password' => 'Click here to reset your password:',
    'serial' => 'Serial',
    'supplier' => 'Supplier',
    'tag' => 'Tag',
    'test_email' => 'Test Email from Snipe-IT',
    'test_mail_text' => 'This is a test from the Snipe-IT Asset Management System. If you got this, mail is working :)',
    'the_following_item' => 'The following item has been checked in: ',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'To reset your :web password, complete this form:',
    'type' => 'Type',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'Welcome :name',
    'welcome_to' => 'Welcome to :web!',
    'your_credentials' => 'Your Snipe-IT credentials',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
    'rights_reserved' => 'All rights reserved.',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/zh-HK/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Days',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Expiring Assets Report.',
    'Expiring_Licenses_Report' => 'Expiring Licenses Report.',
    'Item_Request_Canceled' => 'Item Request Canceled',
    'Item_Requested' => 'Item Requested',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Low Inventory Report',
    'a_user_canceled' => 'A user has canceled an item request on the website',
    'a_user_requested' => 'A user has requested an item on the website',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'Accessory Name:',
    'additional_notes' => 'Additional Notes:',
    'admin_has_created' => 'An administrator has created an account for you on the :web website.',
    'asset' => 'Asset:',
    'asset_name' => 'Asset Name:',
    'asset_requested' => 'Asset requested',
    'asset_tag' => 'Asset Tag',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Assigned To',
    'best_regards' => 'Best regards,',
    'canceled' => 'Canceled:',
    'checkin_date' => 'Checkin Date:',
    'checkout_date' => 'Checkout Date:',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Please click on the link at the bottom to confirm that you have received the accessory.',
    'click_on_the_link_asset' => 'Please click on the link at the bottom to confirm that you have received the asset.',
    'click_to_confirm' => 'Please click on the following link to confirm your :web account:',
    'current_QTY' => 'Current QTY',
    'days' => 'Days',
    'expecting_checkin_date' => 'Expected Checkin Date:',
    'expires' => 'Expires',
    'hello' => 'Hello',
    'hi' => 'Hi',
    'i_have_read' => 'I have read and agree to the terms of use, and have received this item.',
    'inventory_report' => 'Inventory Report',
    'item' => '項目:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'link_to_update_password' => 'Please click on the following link to update your :web password:',
    'login' => 'Login:',
    'login_first_admin' => 'Login to your new Snipe-IT installation using the credentials below:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'min_QTY' => 'Min QTY',
    'name' => 'Name',
    'new_item_checked' => 'A new item has been checked out under your name, details are below.',
    'notes' => 'Notes',
    'password' => 'Password:',
    'password_reset' => 'Password Reset',
    'read_the_terms' => 'Please read the terms of use below.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Requested:',
    'reset_link' => 'Your Password Reset Link',
    'reset_password' => 'Click here to reset your password:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Serial',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Supplier',
    'tag' => 'Tag',
    'test_email' => 'Test Email from Snipe-IT',
    'test_mail_text' => 'This is a test from the Snipe-IT Asset Management System. If you got this, mail is working :)',
    'the_following_item' => 'The following item has been checked in: ',
    'to_reset' => 'To reset your :web password, complete this form:',
    'type' => 'Type',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Welcome :name',
    'welcome_to' => 'Welcome to :web!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Your Snipe-IT credentials',
    'mail_sent' => 'Mail sent successfully!',
];
